(***************************************************************************
 *
 * ML-LEX Scanner for Array Equations
 *
 * Author: Gerald Baumgartner
 * Date:   17 October 2001
 *
 ***************************************************************************)

type svalue = Tokens.svalue;
type pos = int;
type ('a, 'b) token = ('a, 'b) Tokens.token;
type lexresult = (svalue, pos) token;

val pos = ref 1;
fun eof () = Tokens.EOF (!pos, !pos);

%%
%header (functor EqLex (structure Tokens: Eq_TOKENS));
alpha	= [A-Za-z];
digit	= [0-9];
ws	= [\ \t];
id	= {alpha}({alpha}|"_"|{digit})*;
num	= {digit}+;
cmt1	= "#".*;
cmt2	= "/*".*"*/";
%%
\n		=> (pos := !pos + 1; lex());
{ws}+		=> (lex());
{cmt1}		=> (lex());
{cmt2}		=> (lex());
"range"		=> (Tokens.RANGE (!pos, !pos));
"limit"		=> (Tokens.LIMIT (!pos, !pos));
"fcost"		=> (Tokens.FCOST (!pos, !pos));
"sum"		=> (Tokens.SUM (!pos, !pos));
"+"		=> (Tokens.PLUS (!pos, !pos));
"-"		=> (Tokens.MINUS (!pos, !pos));
"*"		=> (Tokens.TIMES (!pos, !pos));
"/"		=> (Tokens.DIV (!pos, !pos));
"("		=> (Tokens.LPAREN (!pos, !pos));
")"		=> (Tokens.RPAREN (!pos, !pos));
"["		=> (Tokens.LBRACK (!pos, !pos));
"]"		=> (Tokens.RBRACK (!pos, !pos));
"{"		=> (Tokens.LBRACE (!pos, !pos));
"}"		=> (Tokens.RBRACE (!pos, !pos));
","		=> (Tokens.COMMA (!pos, !pos));
"=="		=> (Tokens.DEFINE (!pos, !pos));
"write"		=> (Tokens.WRITE (!pos, !pos));
{id}		=> (Tokens.IDENT (yytext, !pos, !pos));
{num}		=> (let val n = IntInf.fromString yytext
		    in
		      case n of
		        SOME i => Tokens.ICONST (i, !pos, !pos)
		      | NONE => (print ("Bad number " ^ yytext ^ " on line " ^
					Int.toString (!pos) ^ "\n");
				 lex()
				)
		    end);
.		=> (print
                      ("Ignoring bad character " ^ yytext ^ " on line " ^
                       Int.toString (!pos) ^ "\n");
                    lex()
                   );
