(***************************************************************************
 *
 * Example Data for the Fusion Algorithm
 *
 * Author: Gerald Baumgartner
 * Date:   29 July 2001
 *
 ***************************************************************************)

open ExpTree

(***************************************************************************
 *
 * Expression Trees for Chi-Chung's Example
 *
 * sum i,j,l A[i,j] B[j,k,l] C[k,l]
 * i 500
 * j 100
 * k 40
 * l 15
 * end
 *
 ***************************************************************************)

val A  = Fun ("A", [("i",500), ("j",100)])
val f1 = Sum (["i"], A)
val B  = Fun ("B", [("j",100),("k",40),("l",15)])
val C  = Fun ("C", [("k",40), ("l",15)])
val f2 = BinOp (Mul, B, C)
val f3 = Sum (["l"], f2)
val f4 = BinOp (Mul, f1, f3)
val f5 = Sum (["j"], f4)

val A'  = Array ("A", [("i",500), ("j",100)])
val f1' = Sum (["i"], A')
val B'  = Array ("B", [("j",100),("k",40),("l",15)])
val C'  = Array ("C", [("k",40), ("l",15)])
val f2' = BinOp (Mul, B', C')
val f3' = Sum (["l"], f2')
val f4' = BinOp (Mul, f1', f3')
val f5' = Sum (["j"], f4')


(***************************************************************************
 *
 * Expression Trees for Marcel's Example
 *
 * sum c,d,e,f,k,l T[a,c,i,k] N[c,d,e,l] D[b,e,f,l] S[d,j,f,k]
 * i,j,k,l 40
 * a,b,c,d 300
 * e,f 70
 * end
 *
 ***************************************************************************)

val T = Array ("T", [("a",300), ("c",300), ("i",40), ("k",40)])
val N = Array ("N", [("c",300), ("d",300), ("e",70), ("l",40)])
val D = Array ("D", [("b",300), ("e",70), ("f",70), ("l",40)])
val S = Array ("S", [("d",300), ("j",40), ("f",70), ("k",40)])

val m1 = BinOp (Mul, N, D)
val m2 = Sum (["e", "l"], m1)
val m3 = BinOp (Mul, S, m2)
val m4 = Sum (["d", "f"], m3)
val m5 = BinOp (Mul, T, m4)
val m6 = Sum (["c", "k"], m5)
