(***************************************************************************
 *
 * Tests for the Index Set Sequence Implementation
 *
 * Author: Gerald Baumgartner
 * Date:   3 June 2001
 *
 ***************************************************************************)

structure TestIndexSetSeq =
  struct
    open IndexSetSeq

    structure ISetSeqSet =
      struct
	type t = iSetSeq
	val eq = op=
	val toString = toString
      end

    structure ISetSeqSet = Set (structure Elem = ISetSeqSet)

    val testSet =
	set [["i", "j"], ["k"]] = ["i", "j", "k"]

    val testPrefix =
	prefix ([["i"], ["j"]], [["i"], ["j", "k"]]) = true

    val testPrefixes =
	let val p = prefixes [["i", "j"], ["k"]]
	in
	  ISetSeqSet.elem ([["i", "j"], ["k"]], p)
	  andalso ISetSeqSet.elem ([["i", "j"]], p)
	  andalso ISetSeqSet.elem ([["i"]], p)
	  andalso ISetSeqSet.elem ([["j"]], p)
	  andalso ISetSeqSet.elem ([], p)
	end

    val testMaxPrefix =
	maxPrefix ([["i"], ["j"], ["k", "l"], ["m"]], ["i", "j", "k"])
	  = [["i"], ["j"], ["k"]]

    val testMerge =
	merge ([["i", "j"], ["k"]], [["i"], ["j", "k"]])
	  = [["i"], ["j"], ["k"]]

    val testExtend =
	extend ([["i", "j"], ["k"]], ["j", "l", "m"])
	  = [["i", "j"], ["k"], ["l", "m"]]

    val testRestrict =
	restrict ([["j", "k", "l"]], [["j"], ["k"]]) = [["j"], ["k"], ["l"]]
	andalso restrict ([["*"]], [["j"], ["k"]]) = [["j"], ["k"]]

    val testSuffix =
	suffix ([["i", "j"], ["k"]], [["i", "j"]]) = [["k"]]

    val testLeq =
	leq ([["i", "j"], ["k"]], [["i", "j", "k"]]) = true

    val testToString =
	toString [["i", "j"], ["k"]] = "<ij, k>"

    val ok = testSet
        andalso testPrefix
        andalso testPrefixes
        andalso testMaxPrefix
        andalso testMerge
        andalso testExtend
        andalso testRestrict
	andalso testSuffix
        andalso testLeq
        andalso testToString
  end
